@@ -5,11 +5,11 @@
 #' @param extn the extension of the image: png, jpeg ...
 #' @param askRobot logical. Should the function ask the robots.txt if we're allowed or not to scrape the web page ? Default is FALSE.
 #'
-#' @return Images
+#' @return called for the side effect of downloading images
 #'
 #' @examples \dontrun{
 #'
-#' images_scrap(link = "https://rstudio.com/", extn = "png")
+#' images_scrap(link = "https://posit.co/", extn = "jpg")
 #'
 #' }
 #'
@@ -96,10 +96,21 @@ images_scrap <- function(link,
                                   x = img_urls_unlist,
                                   ignore.case = FALSE)]
 
+    if (length(img_urls_f) == 0) {
+      message("No image has been found. Returning NULL")
+      return(invisible(NULL))
+    }
+
+    img_urls_f <- purrr::map_chr(
+      img_urls_f,
+      .format_url,
+      link = link
+    )
+
     for (i in seq_along(img_urls_f)) {
 
       download.file(img_urls_f[i],
-                    destfile = basename(img_urls_f[i]),
+                    destfile = paste0(imgpath, "/", basename(img_urls_f[i])),
                     mode = "wb")
 
     }
